@@ -1,6 +1,7 @@
 """MySQLdb wrapper for easy usage and encryption"""
 
-import signal
+# TODO in v1: fields alsoAsHash attribute
+
 import copy
 import datetime
 import logging
@@ -18,26 +19,6 @@ MYSQL_SERVER_IS_GONE = 2006
 MYSQL_TABLE_ALREADY_EXISTS = 1050
 
 
-class TimeoutError(Exception):
-    pass
-
-
-class timeout:
-    def __init__(self, seconds=2, error_message="Timeout"):
-        self.seconds = seconds
-        self.error_message = error_message
-
-    def handle_timeout(self, signum, frame):
-        raise TimeoutError(self.error_message)
-
-    def __enter__(self):
-        signal.signal(signal.SIGALRM, self.handle_timeout)
-        signal.alarm(self.seconds)
-
-    def __exit__(self, type, value, traceback):
-        signal.alarm(0)
-
-
 class Empty:
     pass
 
@@ -92,18 +73,19 @@ class Base(metaclass=BaseMetaclass):
                 setattr(self, key, value)
         self._session = session
 
-    @classmethod
-    def get_from_id(cls, session, obj_id):
-        return session.query(cls).where(cls.id == obj_id).first()
-
     def __deepcopy__(self, memo):
         new_obj = self.__class__(self._session)
         for key, value in self.get_table_dict().items():
             setattr(new_obj, key, copy.deepcopy(value, memo))
         return new_obj
 
+    @classmethod
+    def get_from_id(cls, session, obj_id):
+        return session.query(cls).where(cls.id == obj_id).first()
+
     @ClassOrInstanceMethod
     def get_table_dict(self):
+        """Gets all fields of the table."""
         table_dict = {}
         for key, value in vars(self).items():
             if key.startswith("_") or isinstance(value, (property, classmethod, staticmethod)) or callable(value):
@@ -111,7 +93,17 @@ class Base(metaclass=BaseMetaclass):
             table_dict[key] = value
         return table_dict
 
+    def get_api_dict(self):
+        """Gets all fields of the table, except bytes field."""
+        table_dict = self.get_table_dict()
+        api_dict = {}
+        for key, value in table_dict.items():
+            if not isinstance(object.__getattribute__(type(self), key), bytes):
+                api_dict[key] = value
+        return api_dict
+
     def get_complete_dict(self):
+        """Gets all fields of the table, and of the subtables present in the object. (Id fields are subtables)"""
         complete_dict = self.get_table_dict()
         for key, value in vars(type(self)).items():
             if isinstance(value, property):
@@ -160,8 +152,7 @@ class Cursor:
     def execute(self, query, args=None):
         self.logger.info(query)
         try:
-            with timeout():
-                self.cursor.execute(query, args)
+            self.cursor.execute(query, args)
         except MySQLdb.OperationalError as e:
             error_code, _ = e.args
             if error_code != MYSQL_SERVER_IS_GONE:
@@ -170,13 +161,6 @@ class Cursor:
             new_cursor = self.db.cursor(self.cursorclass)
             self.cursor = new_cursor.cursor
             self.cursor.execute(query, args)
-        except TimeoutError:
-            self.logger.error("Timeout on cursor execute")
-            self.db.close()
-            self.db.reconnect()
-            new_cursor = self.db.cursor(self.cursorclass)
-            self.cursor = new_cursor.cursor
-            self.cursor.execute(query, args)
 
 
 class Database:
@@ -230,26 +214,15 @@ class Database:
         return Cursor(cursor, cursorclass, self)
 
     def commit(self):
-        retry = False
-        while True:
-            try:
-                with timeout():
-                    self.db.commit()
-                return
-            except MySQLdb.OperationalError as e:
-                error_code, _ = e.args
-                if error_code != MYSQL_SERVER_IS_GONE:
-                    raise e
-                self.reconnect()
-                return
-            except TimeoutError:
-                self.logger.error("Timeout on commit")
-                if not retry:
-                    retry = True
-                    continue
-                self.close()
-                self.reconnect()
-                return
+        try:
+            self.db.commit()
+            return
+        except MySQLdb.OperationalError as e:
+            error_code, _ = e.args
+            if error_code != MYSQL_SERVER_IS_GONE:
+                raise e
+            self.reconnect()
+            return
 
 
 class Session:
